==> haskell-uri-encode-1.5.0.7-241-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uri-encode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 uri-encode
version:              1.5.0.7
visibility:           public
id:                   uri-encode-1.5.0.7-4LOB7sXGmqbAT67Q5T2yci
key:                  uri-encode-1.5.0.7-4LOB7sXGmqbAT67Q5T2yci
license:              BSD-3-Clause
maintainer:           code@silk.co
author:               Silk
synopsis:             Unicode aware uri-encoding
description:
    This package allows you to uri encode and uri decode
    Strings, Texts and ByteString values.

category:             Network, Web
abi:                  8e34f4c2fe506d2e8b21d81613087d55
exposed:              True
exposed-modules:      Network.URI.Encode
import-dirs:          /usr/lib/ghc-9.4.8/site-local/uri-encode-1.5.0.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/uri-encode-1.5.0.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/uri-encode-1.5.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uri-encode
hs-libraries:         HSuri-encode-1.5.0.7-4LOB7sXGmqbAT67Q5T2yci
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    network-uri-2.6.4.2-LI9nyHI8pqjDGXx8FK9BWe text-2.0.2
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm

haddock-interfaces:   /usr/share/doc/haskell-uri-encode/html/uri-encode.haddock
haddock-html:         /usr/share/doc/haskell-uri-encode/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uri-encode-1.5.0.7-242-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uri-encode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 uri-encode
version:              1.5.0.7
visibility:           public
id:                   uri-encode-1.5.0.7-7EhvalZg93rFRF7FzULSD5
key:                  uri-encode-1.5.0.7-7EhvalZg93rFRF7FzULSD5
license:              BSD-3-Clause
maintainer:           code@silk.co
author:               Silk
synopsis:             Unicode aware uri-encoding
description:
    This package allows you to uri encode and uri decode
    Strings, Texts and ByteString values.

category:             Network, Web
abi:                  58727c6e3b843e06eaf87a08b06cc740
exposed:              True
exposed-modules:      Network.URI.Encode
import-dirs:          /usr/lib/ghc-9.4.8/site-local/uri-encode-1.5.0.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/uri-encode-1.5.0.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/uri-encode-1.5.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uri-encode
hs-libraries:         HSuri-encode-1.5.0.7-7EhvalZg93rFRF7FzULSD5
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    network-uri-2.6.4.2-F7iehLTgVhD13GIPVpEkB1 text-2.0.2
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm

haddock-interfaces:   /usr/share/doc/haskell-uri-encode/html/uri-encode.haddock
haddock-html:         /usr/share/doc/haskell-uri-encode/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
